// Copyright (C) 2015 The Android Open Source Project
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.google.gerrit.acceptance.rest.project;

import static com.google.common.truth.Truth.assertThat;

import com.google.gerrit.acceptance.AbstractDaemonTest;
import com.google.gerrit.acceptance.RestResponse;
import com.google.gerrit.extensions.common.ProjectInfo;

import org.apache.http.HttpStatus;
import org.junit.Test;

public class GetProjectIT extends AbstractDaemonTest {

  @Test
  public void getProject() throws Exception {
    String name = project.get();
    RestResponse r = adminSession.get("/projects/" + name);
    assertThat(r.getStatusCode()).isEqualTo(HttpStatus.SC_OK);
    ProjectInfo p = newGson().fromJson(r.getReader(), ProjectInfo.class);
    assertThat(p.name).isEqualTo(name);
  }

  @Test
  public void getProjectWithGitSuffix() throws Exception {
    String name = project.get();
    RestResponse r = adminSession.get("/projects/" + name + ".git");
    assertThat(r.getStatusCode()).isEqualTo(HttpStatus.SC_OK);
    ProjectInfo p = newGson().fromJson(r.getReader(), ProjectInfo.class);
    assertThat(p.name).isEqualTo(name);
  }

  @Test
  public void getProjectNotExisting() throws Exception {
    RestResponse r = adminSession.get("/projects/does-not-exist");
    assertThat(r.getStatusCode()).isEqualTo(HttpStatus.SC_NOT_FOUND);
  }
}
